'use server';

import { createServerClient } from '@/utils/supabase';
import Image from 'next/image';

export default async function Page() {
  const supabase = await createServerClient();

  // Get authenticated user
  const {
    data: { user: authUser },
    error: userError,
  } = await supabase.auth.getUser();

  if (userError || !authUser) {
    return (
      <div>
        Error loading user: {userError?.message ?? 'User not authenticated'}
      </div>
    );
  }

  // Get user profile
  const { data: user, error: profileError } = await supabase
    .from('profiles')
    .select('*')
    .eq('id', authUser.id)
    .single();

  if (profileError || !user) {
    return (
      <div>
        Error loading profile: {profileError?.message ?? 'Profile not found'}
      </div>
    );
  }

  // Check if avatar URL exists
  if (!user.avatar_url) {
    return <div>No avatar image available</div>;
  }

  // Get public URL for the avatar
  const { data: imageData } = await supabase.storage
    .from('avatars')
    .createSignedUrl(user.avatar_url, 3600);

  return (
    <div className='flex justify-center items-center p-8'>
      <Image
        src={imageData?.signedUrl ?? '/images/default_pfp.png'}
        alt='User avatar'
        width={150}
        height={150}
        className='rounded-full'
        priority
      />
    </div>
  );
}
